wurfl2python.DeviceSerializer

Module wurfl2python :: Class DeviceSerializer |
[hide private]
[frames] | no frames]

# Class DeviceSerializer

source code

                              object --+
                                       |
    pywurfl.wurflprocessor.DeviceHandler --+
                                           |
                                          DeviceSerializer

Instance Methods | [hide private]
__str__(self) str(x) | source code
Inherited from `pywurfl.wurflprocessor.DeviceHandler`: `__init__` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Variables | [hide private]
| idstr = ``'``devices.devids[\'\'\'%s\'\'\'] =` `'``
| new_caps = ``'``devices.devids[\'\'\'%s\'\'\'] = devclass(%s, \'\'``...``
| no_caps = ``'``devices.devids[\'\'\'%s\'\'\'] = devclass(%s, \'\'\``...``
| capability_types = ``{``}``

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)

Class Variable Details | [hide private]

  ### new_caps Value:
      '''devices.devids[\'\'\'%s\'\'\'] = devclass(%s, \'\'\'%s\'\'\', \'\'\
      '%s\'\'\', %s, {%s})
      '''

  ### no_caps Value:
      '''devices.devids[\'\'\'%s\'\'\'] = devclass(%s, \'\'\'%s\'\'\', \'\'\
      '%s\'\'\', %s, None)
      '''